@@ -14,18 +14,11 @@
 #' \item{`finbif_tz`}{Character. The timezone used by `finbif` functions that
 #'   compute dates and times. Default: `Sys.timezone()`}
 #' \item{`finbif_locale`}{Character. One of the supported two-letter ISO 639-1
-#'   language codes. Current supported languages are English, Finnish, Swedish,
-#'   Russian, and Sámi (Northern). By default, the system settings are used to
-#'   set this option if they are set to one of the supported languages,
-#'   otherwise English is used.}
+#'   language codes. Current supported languages are English, Finnish and
+#'   Swedish. By default, the system settings are used to set this option if
+#'   they are set to one of the supported languages, otherwise English is used.}
 #' \item{`finbif_hide_progress`}{Logical. Global option to suppress progress
 #'   indicators for downloading, importing and processing FinBIF records.
 #'   Default: `FALSE`}
 #' }
 "_PACKAGE"
-
-# The following block is used by usethis to automatically manage
-# roxygen namespace tags. Modify with care!
-## usethis namespace: start
-## usethis namespace: end
-NULL
