@@ -51,3 +51,23 @@ test_that(
 
   }
 )
+
+test_that(
+  "name_chr_vec with no args returns NULL", {
+
+    expect_equal(name_chr_vec(), NULL)
+
+  }
+)
+
+test_that(
+  "deprecation warning works", {
+
+    Sys.setenv(DEPRECATION_WARNING = TRUE)
+
+    expect_warning(deprecation("msg"), "msg")
+
+    Sys.setenv(DEPRECATION_WARNING = FALSE)
+
+  }
+)
